@@ -66,8 +66,10 @@ class WlkataMirobot(AbstractContextManager):
 		'''初始化'''
   		# 设置日志等级
 		self.logger = logging.getLogger(__name__)
-		
-		self.logger.setLevel(logging.DEBUG)
+		if (debug):
+			self.logger.setLevel(logging.DEBUG)
+		else:
+			self.logger.setLevel(logging.ERROR)
 
 		self.stream_handler = ExitOnExceptionStreamHandler()
 		self.stream_handler.setLevel(logging.DEBUG if debug else logging.INFO)
@@ -381,19 +383,42 @@ class WlkataMirobot(AbstractContextManager):
 		else:
 			return 	self.go_to_axis(d=d,
 									speed=speed, wait_ok=wait_ok, is_relative=True)
-   
-	def set_tool_pose(self, x=None, y=None, z=None, roll=0.0, pitch=0.0, yaw=0.0, mode='p2p', speed=None, is_relative=False, wait_ok=True):
+	
+	def set_conveyor_range(self, d_min=-30000, d_max=30000):
+		'''设置传送带的位移范围'''
+		# 约束范围
+		if d_min < -30000:
+			d_min = -30000
+		if d_max > 30000:
+			d_min = 30000
+		# 设置传动带负方向最大行程
+		msg = f"$143={d_min}"
+		self.send_msg(msg, wait_ok=True, wait_idle=True)
+		# 设置传送带正方向最大行程
+		msg = f'$133={d_max}'
+		self.send_msg(msg, wait_ok=True, wait_idle=True)
+
+	def set_conveyor_posi(self, d, speed=None, is_relative=False, wait_ok=True):
+		'''设置传送带位置, 单位mm'''
+		if not is_relative:
+			return 	self.go_to_axis(d=d,
+									speed=speed, wait_ok=wait_ok)
+		else:
+			return 	self.go_to_axis(d=d,
+									speed=speed, wait_ok=wait_ok, is_relative=True)
+	
+	def set_tool_pose(self, x=None, y=None, z=None, roll=None, pitch=None, yaw=None, mode='p2p', speed=None, is_relative=False, wait_ok=True):
 		'''设置工具位姿'''
 		if mode == "p2p":
 			# 点控模式 Point To Point
-			self.p2p_interpolation(x=x, y=y, z=z, a=yaw, b=pitch, c=yaw, speed=speed, is_relative=is_relative, wait_ok=wait_ok)
+			self.p2p_interpolation(x=x, y=y, z=z, a=roll, b=pitch, c=yaw, speed=speed, is_relative=is_relative, wait_ok=wait_ok)
 		elif mode == "linear":
 			# 直线插补 Linera Interpolation
-			self.linear_interpolation(x=x, y=y, z=z, a=yaw, b=pitch, c=yaw, speed=speed,is_relative=is_relative, wait_ok=wait_ok)
+			self.linear_interpolation(x=x, y=y, z=z, a=roll, b=pitch, c=yaw, speed=speed,is_relative=is_relative, wait_ok=wait_ok)
 		else:
 			# 默认是点到点
-			self.p2p_interpolation(x=x, y=y, z=z, a=yaw, b=pitch, c=yaw, speed=speed, wait_ok=wait_ok)
-   
+			self.p2p_interpolation(x=x, y=y, z=z, a=roll, b=pitch, c=yaw, speed=speed, wait_ok=wait_ok)
+	
 	def p2p_interpolation(self, x=None, y=None, z=None, a=None, b=None, c=None, speed=None, is_relative=False, wait_ok=None):
 		'''点到点插补'''
 		instruction = 'M20 G90 G0'  # X{x} Y{y} Z{z} A{a} B{b} C{c} F{speed}
@@ -646,6 +671,11 @@ class WlkataMirobot(AbstractContextManager):
 		'''获取滑台(Mirobot第七轴)的位置'''
 		return self.status.angle.d
 
+	@property
+	def conveyor(self):
+		'''获取传送带(Mirobot第七轴)的位置'''
+		return self.status.angle.d
+
 	@property
 	def valve_pwm(self):
 		'''电磁阀的PWM'''
